@@ -10,7 +10,7 @@ class MyClass : public sigc::trackable
   public:
     MyClass(void)
     {
-      con = new TcpClient("www.linux.org", 80);
+      con = new TcpClient<>("www.linux.org", 80);
       con->connected.connect(mem_fun(*this, &MyClass::onConnected));
       con->disconnected.connect(mem_fun(*this, &MyClass::onDisconnected));
       con->dataReceived.connect(mem_fun(*this, &MyClass::onDataReceived));
@@ -23,7 +23,7 @@ class MyClass : public sigc::trackable
     }
 
   private:
-    TcpClient *con;
+    TcpClient<>* con;
     
     void onConnected(void)
     {
@@ -31,7 +31,7 @@ class MyClass : public sigc::trackable
       con->write("GET /\n", 6);
     }
     
-    void onDisconnected(TcpConnection *con, TcpClient::DisconnectReason reason)
+    void onDisconnected(TcpConnection *con, TcpClient<>::DisconnectReason reason)
     {
       cout << "Disconnected from " << con->remoteHost() << "...\n";
       Application::app().quit();
