@@ -6,7 +6,7 @@
 
 \verbatim
 SvxLink - A Multi Purpose Voice Services System for Ham Radio Use
-Copyright (C) 2003-2009 Tobias Blomberg / SM0SVX
+Copyright (C) 2003-2015 Tobias Blomberg / SM0SVX
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -183,6 +183,9 @@ bool LocationInfo::initialize(const Async::Config &cfg, const std::string &cfg_n
   LocationInfo::_instance->sinterval = iv;
   LocationInfo::_instance->startStatisticsTimer(iv*60000);
 
+  value = cfg.getValue(cfg_name, "PTY_PATH");
+  LocationInfo::_instance->initExtPty(value);
+
   if( !init_ok )
   {
     delete LocationInfo::_instance;
@@ -480,7 +483,7 @@ int LocationInfo::calculateRange(const Cfg &cfg)
   }
 
   double tmp = sqrt(2.0 * loc_cfg.height * sqrt((loc_cfg.power / 10.0) *
-                        pow10(loc_cfg.gain / 10.0) / 2)) * range_factor;
+                        pow(10, loc_cfg.gain / 10.0) / 2)) * range_factor;
 
   return lrintf(tmp);
 
@@ -601,6 +604,7 @@ bool LocationInfo::parseClientStr(string &host, int &port, const string &val)
 
 
 void LocationInfo::startStatisticsTimer(int interval) {
+  delete aprs_stats_timer;
   aprs_stats_timer = new Timer(interval, Timer::TYPE_PERIODIC);
   aprs_stats_timer->setEnable(true);
   aprs_stats_timer->expired.connect(mem_fun(*this, &LocationInfo::sendAprsStatistics));
@@ -613,7 +617,7 @@ void LocationInfo::sendAprsStatistics(Timer *t)
   info[0] ='\0';
   string head ="UNIT.RX Erlang,TX Erlang,RXcount/10m,TXcount/10m,none1,STxxxxxx,logic";
 
-  sprintf(info, "E%s-%s>RXTLM-1,TCPIP,qAR,%s::E%s-%s:%s\n",
+  sprintf(info, "E%s-%s>RXTLM-1,TCPIP,qAR,%s::E%s-%-6s:%s\n",
        loc_cfg.prefix.c_str(), loc_cfg.mycall.c_str(), loc_cfg.mycall.c_str(),
        loc_cfg.prefix.c_str(), loc_cfg.mycall.c_str(), head.c_str());
 
@@ -679,6 +683,35 @@ void LocationInfo::sendAprsStatistics(Timer *t)
 } /* LocationInfo::sendAprsStatistics */
 
 
+void LocationInfo::initExtPty(std::string ptydevice)
+{
+  AprsPty *aprspty = new AprsPty();
+  if (!aprspty->initialize(ptydevice))
+  {
+     cout << "*** ERROR: initializing aprs pty device " << ptydevice << endl;
+  }
+  else
+  {
+     aprspty->messageReceived.connect(mem_fun(*this,
+                    &LocationInfo::mesReceived));
+  }
+} /* LocationInfo::initExtPty */
+
+
+void LocationInfo::mesReceived(std::string message)
+{
+  string loc_call = LocationInfo::getCallsign();
+  size_t found = message.find("XXXXXX");
+
+  if (found != std::string::npos)
+  {
+    message.replace(found, 6, loc_call);
+  }
+
+  igateMessage(message);
+  cout << message << endl;
+} /* LocationInfo::mesReceived */
+
 
 /****************************************************************************
  *
