@@ -8,7 +8,7 @@ This file contains a class that handle local digital drop receivers.
 
 \verbatim
 SvxLink - A Multi Purpose Voice Services System for Ham Radio Use
-Copyright (C) 2004-2014 Tobias Blomberg / SM0SVX
+Copyright (C) 2004-2018 Tobias Blomberg / SM0SVX
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -130,8 +130,7 @@ namespace {
         this->taps = taps;
 
         delete [] p_Z;
-        p_Z = new T[taps];
-        memset(p_Z, 0, taps * sizeof(*p_Z));
+        p_Z = new T[taps]();
       }
 
       void setGain(double gain_adjust)
@@ -996,7 +995,7 @@ class Ddr::Channel : public sigc::trackable, public Async::AudioSource
              << ". Legal values are: 960000 and 2400000\n";
         return false;
       }
-      setModulation(Ddr::MOD_FM);
+      setModulation(Modulation::MOD_FM);
       channelizer->preDemod.connect(preDemod.make_slot());
       return true;
     }
@@ -1007,36 +1006,36 @@ class Ddr::Channel : public sigc::trackable, public Async::AudioSource
       trans.setOffset(fq_offset - ch_offset);
     }
 
-    void setModulation(Ddr::Modulation mod)
+    void setModulation(Modulation::Type mod)
     {
       demod = 0;
       ch_offset = 0;
       switch (mod)
       {
-        case Ddr::MOD_FM:
+        case Modulation::MOD_FM:
           channelizer->setBw(Channelizer::BW_20K);
           fm_demod.setDemodParams(channelizer->chSampRate(), 5000);
           demod = &fm_demod;
           break;
-        case Ddr::MOD_NBFM:
+        case Modulation::MOD_NBFM:
           channelizer->setBw(Channelizer::BW_10K);
           fm_demod.setDemodParams(channelizer->chSampRate(), 2500);
           demod = &fm_demod;
           break;
-        case Ddr::MOD_WBFM:
+        case Modulation::MOD_WBFM:
           channelizer->setBw(Channelizer::BW_WIDE);
           fm_demod.setDemodParams(channelizer->chSampRate(), 75000);
           demod = &fm_demod;
           break;
-        case Ddr::MOD_AM:
+        case Modulation::MOD_AM:
           channelizer->setBw(Channelizer::BW_10K);
           demod = &am_demod;
           break;
-        case Ddr::MOD_NBAM:
+        case Modulation::MOD_NBAM:
           channelizer->setBw(Channelizer::BW_6K);
           demod = &am_demod;
           break;
-        case Ddr::MOD_USB:
+        case Modulation::MOD_USB:
 #ifdef USE_SSB_PHASE_DEMOD
           channelizer->setBw(Channelizer::BW_6K);
 #else
@@ -1046,7 +1045,7 @@ class Ddr::Channel : public sigc::trackable, public Async::AudioSource
           ssb_demod.useLsb(false);
           demod = &ssb_demod;
           break;
-        case Ddr::MOD_LSB:
+        case Modulation::MOD_LSB:
 #ifdef USE_SSB_PHASE_DEMOD
           channelizer->setBw(Channelizer::BW_6K);
 #else
@@ -1056,14 +1055,16 @@ class Ddr::Channel : public sigc::trackable, public Async::AudioSource
           ssb_demod.useLsb(true);
           demod = &ssb_demod;
           break;
-        case Ddr::MOD_CW:
+        case Modulation::MOD_CW:
           channelizer->setBw(Channelizer::BW_500);
           demod = &cw_demod;
           break;
-        case Ddr::MOD_WBCW:
+        case Modulation::MOD_WBCW:
           channelizer->setBw(Channelizer::BW_3K);
           demod = &cw_demod;
           break;
+        case Modulation::MOD_UNKNOWN:
+          break;
       }
       setFqOffset(fq_offset);
       assert((demod != 0) && "Channel::setModulation: Unknown modulation");
@@ -1232,41 +1233,10 @@ bool Ddr::initialize(void)
 
   string modstr("FM");
   cfg.getValue(name(), "MODULATION", modstr);
-  if (modstr == "FM")
+  Modulation::Type mod = Modulation::fromString(modstr);
+  if (mod != Modulation::MOD_UNKNOWN)
   {
-    channel->setModulation(MOD_FM);
-  }
-  else if (modstr == "NBFM")
-  {
-    channel->setModulation(MOD_NBFM);
-  }
-  else if (modstr == "WBFM")
-  {
-    channel->setModulation(MOD_WBFM);
-  }
-  else if (modstr == "AM")
-  {
-    channel->setModulation(MOD_AM);
-  }
-  else if (modstr == "NBAM")
-  {
-    channel->setModulation(MOD_NBAM);
-  }
-  else if (modstr == "USB")
-  {
-    channel->setModulation(MOD_USB);
-  }
-  else if (modstr == "LSB")
-  {
-    channel->setModulation(MOD_LSB);
-  }
-  else if (modstr == "CW")
-  {
-    channel->setModulation(MOD_CW);
-  }
-  else if (modstr == "WBCW")
-  {
-    channel->setModulation(MOD_WBCW);
+    channel->setModulation(mod);
   }
   else
   {
@@ -1292,33 +1262,10 @@ bool Ddr::initialize(void)
 
 void Ddr::tunerFqChanged(uint32_t center_fq)
 {
-  if (channel == 0)
-  {
-    return;
-  }
-
-  int new_offset = fq - center_fq;
-  if (static_cast<uint32_t>(abs(new_offset)) > (rtl->sampleRate() / 2)-12500)
-  {
-    if (channel->isEnabled())
-    {
-      cout << "*** WARNING: Could not fit DDR " << name() << " into tuner "
-           << rtl->name() << endl;
-      channel->disable();
-    }
-    return;
-  }
-  channel->setFqOffset(new_offset);
-  channel->enable();
+  updateFqOffset();
 } /* Ddr::tunerFqChanged */
 
 
-void Ddr::setModulation(Modulation mod)
-{
-  channel->setModulation(mod);
-} /* Ddr::setModulation */
-
-
 unsigned Ddr::preDemodSampleRate(void) const
 {
   return channel->chSampRate();
@@ -1331,6 +1278,20 @@ bool Ddr::isReady(void) const
 } /* Ddr::isReady */
 
 
+void Ddr::setFq(unsigned fq)
+{
+  this->fq = fq;
+  rtl->updateDdrFq(this);
+  updateFqOffset();
+} /* Ddr::setFq */
+
+
+void Ddr::setModulation(Modulation::Type mod)
+{
+  channel->setModulation(mod);
+} /* Ddr::setModulation */
+
+
 
 /****************************************************************************
  *
@@ -1368,6 +1329,30 @@ Async::AudioSource *Ddr::audioSource(void)
  *
  ****************************************************************************/
 
+void Ddr::updateFqOffset(void)
+{
+  if ((channel == 0) || (rtl == 0))
+  {
+    return;
+  }
+
+  double new_offset = fq - rtl->centerFq();
+  if (abs(new_offset) > (rtl->sampleRate() / 2)-12500)
+  {
+    if (channel->isEnabled())
+    {
+      cout << "*** WARNING: Could not fit DDR \"" << name() 
+           << "\" with frequency " << fq << "Hz into tuner " 
+           << rtl->name() << endl;
+      channel->disable();
+    }
+    return;
+  }
+  channel->setFqOffset(new_offset);
+  channel->enable();
+} /* Ddr::updateFqOffset */
+
+
 
 /*
  * This file has not been truncated
