@@ -6,7 +6,7 @@
 
 \verbatim
 SvxLink - A Multi Purpose Voice Services System for Ham Radio Use
-Copyright (C) 2003-2008 Tobias Blomberg / SM0SVX
+Copyright (C) 2003-2018 Tobias Blomberg / SM0SVX
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -133,8 +133,9 @@ class ToneDet
 NetRx::NetRx(Config &cfg, const string& name)
   : Rx(cfg, name), cfg(cfg), mute_state(Rx::MUTE_ALL), tcp_con(0),
     log_disconnects_once(false), log_disconnect(true),
-    last_signal_strength(0.0), last_sql_rx_id(0), unflushed_samples(false),
-    sql_is_open(false), audio_dec(0)
+    last_signal_strength(0.0), last_sql_rx_id(Rx::ID_UNKNOWN),
+    unflushed_samples(false), sql_is_open(false), audio_dec(0), fq(0),
+    modulation(Modulation::MOD_UNKNOWN)
 {
 } /* NetRx::NetRx */
 
@@ -249,7 +250,7 @@ void NetRx::setMuteState(Rx::MuteState new_mute_state)
 
         case MUTE_ALL:  // MUTE_CONTENT -> MUTE_ALL
           last_signal_strength = 0.0;
-          last_sql_rx_id = 0;
+          last_sql_rx_id = Rx::ID_UNKNOWN;
           sql_is_open = false;
           if (!unflushed_samples)
           {
@@ -299,7 +300,7 @@ void NetRx::reset(void)
   
   mute_state = Rx::MUTE_ALL;
   last_signal_strength = 0;
-  last_sql_rx_id = 0;
+  last_sql_rx_id = Rx::ID_UNKNOWN;
   sql_is_open = false;
   
   if (unflushed_samples)
@@ -317,6 +318,22 @@ void NetRx::reset(void)
 } /* NetRx::reset */
 
 
+void NetRx::setFq(unsigned fq)
+{
+  this->fq = fq;
+  MsgSetRxFq *msg = new MsgSetRxFq(fq);
+  sendMsg(msg);
+} /* NetRx::setFq */
+
+
+void NetRx::setModulation(Modulation::Type mod)
+{
+  modulation = mod;
+  MsgSetRxModulation *msg = new MsgSetRxModulation(mod);
+  sendMsg(msg);
+} /* NetRx::setModulation */
+
+
 
 /****************************************************************************
  *
@@ -355,7 +372,19 @@ void NetRx::connectionReady(bool is_ready)
                                 (*it)->required_duration);
       sendMsg(msg);
     }
+
+    if (fq > 0)
+    {
+      MsgSetRxFq *msg = new MsgSetRxFq(fq);
+      sendMsg(msg);
+    }
     
+    if (modulation != Modulation::MOD_UNKNOWN)
+    {
+      MsgSetRxModulation *msg = new MsgSetRxModulation(modulation);
+      sendMsg(msg);
+    }
+
     MsgAudioCodecSelect *msg = new MsgRxAudioCodecSelect(audio_dec->name());
     string opt_prefix(audio_dec->name());
     opt_prefix += "_ENC_";
